@@ -197,10 +197,10 @@ int c_set_window_geometry2(lua_State *lua)
 		return 0;
 	}
 
-	int type1=lua_type(lua, 1);
-	int type2=lua_type(lua, 2);
-	int type3=lua_type(lua, 3);
-	int type4=lua_type(lua, 4);
+	int type1 = lua_type(lua, 1);
+	int type2 = lua_type(lua, 2);
+	int type3 = lua_type(lua, 3);
+	int type4 = lua_type(lua, 4);
 
 	if ((type1!=LUA_TNUMBER) ||
 	    (type2!=LUA_TNUMBER) ||
@@ -210,10 +210,10 @@ int c_set_window_geometry2(lua_State *lua)
 		return 0;
 	}
 
-	int x=lua_tonumber(lua, 1);
-	int y=lua_tonumber(lua, 2);
-	int xsize=lua_tonumber(lua, 3);
-	int ysize=lua_tonumber(lua, 4);
+	int x = lua_tonumber(lua, 1);
+	int y = lua_tonumber(lua, 2);
+	int xsize = lua_tonumber(lua, 3);
+	int ysize = lua_tonumber(lua, 4);
 
 	if (!devilspie2_emulate) {
 		WnckWindow *window = get_current_window();
@@ -242,16 +242,16 @@ int c_set_window_position(lua_State *lua)
 		return 0;
 	}
 
-	int type1=lua_type(lua, 1);
-	int type2=lua_type(lua, 2);
+	int type1 = lua_type(lua, 1);
+	int type2 = lua_type(lua, 2);
 
 	if ((type1!=LUA_TNUMBER) || (type2!=LUA_TNUMBER)) {
 		luaL_error(lua, "set_window_position: %s", two_indata_expected_error);
 		return 0;
 	}
 
-	int x=lua_tonumber(lua, 1);
-	int y=lua_tonumber(lua, 2);
+	int x = lua_tonumber(lua, 1);
+	int y = lua_tonumber(lua, 2);
 
 	if (!devilspie2_emulate) {
 
@@ -281,16 +281,16 @@ int c_set_window_position2(lua_State *lua)
 		return 0;
 	}
 
-	int type1=lua_type(lua,1);
-	int type2=lua_type(lua,2);
+	int type1 = lua_type(lua,1);
+	int type2 = lua_type(lua,2);
 
 	if ((type1!=LUA_TNUMBER) || (type2!=LUA_TNUMBER)) {
 		luaL_error(lua,"set_window_position2: %s", two_indata_expected_error);
 		return 0;
 	}
 
-	int x=lua_tonumber(lua,1);
-	int y=lua_tonumber(lua,2);
+	int x = lua_tonumber(lua,1);
+	int y = lua_tonumber(lua,2);
 
 	if (!devilspie2_emulate) {
 
@@ -319,8 +319,8 @@ int c_set_window_size(lua_State *lua)
 		return 0;
 	}
 
-	int type1=lua_type(lua,1);
-	int type2=lua_type(lua,2);
+	int type1 = lua_type(lua,1);
+	int type2 = lua_type(lua,2);
 
 	if ((type1!=LUA_TNUMBER) || (type2!=LUA_TNUMBER)) {
 		luaL_error(lua,"set_window_size: %s", two_indata_expected_error);
@@ -355,6 +355,46 @@ int c_set_window_size(lua_State *lua)
 	return 0;
 }
 
+/**
+ * Sets the window strut
+ */
+int c_set_window_strut(lua_State *lua)
+{
+	int top = lua_gettop(lua);
+
+	if (top < 4) {
+		luaL_error(lua,"set_window_strut: %s", four_indata_expected_error);
+		return 0;
+	}
+
+	if (!devilspie2_emulate) {
+		#if __x86_64__
+		int64_t struts[12];
+		#else
+		int32_t struts[12];
+		#endif
+		int i;
+		for (i = 0; i < 12; i++) {
+			struts[i] = i < top ? lua_tonumber(lua, i + 1) : 0;
+		}
+
+		Display *dpy = gdk_x11_get_default_xdisplay();
+		WnckWindow *window = get_current_window();
+
+		if (window) {
+			XChangeProperty(dpy,
+							wnck_window_get_xid(window),
+							XInternAtom(dpy, "_NET_WM_STRUT_PARTIAL", False), XA_CARDINAL,
+							32,
+							PropModeReplace,
+							(unsigned char*)struts,
+							12);
+			XSync(dpy, False);
+		}
+	}
+
+	return 0;
+}
 
 /**
  * Sets the window on top of all others and locks it "always on top"
@@ -669,7 +709,7 @@ int c_set_window_workspace(lua_State *lua)
 		return 0;
 	}
 
-	int type=lua_type(lua, 1);
+	int type = lua_type(lua, 1);
 
 	if (type!=LUA_TNUMBER) {
 		luaL_error(lua, "set_window_workspace: %s",
@@ -677,7 +717,7 @@ int c_set_window_workspace(lua_State *lua)
 		return 0;
 	}
 
-	int number=lua_tonumber(lua, 1);
+	int number = lua_tonumber(lua, 1);
 
 	WnckWindow *window = get_current_window();
 
@@ -724,7 +764,7 @@ int c_change_workspace(lua_State *lua)
 		return 0;
 	}
 
-	int number=lua_tonumber(lua, 1);
+	int number = lua_tonumber(lua, 1);
 
 	WnckWindow *window = get_current_window();
 	if (window) {
@@ -1041,7 +1081,7 @@ int c_set_skip_tasklist(lua_State *lua)
 		return 0;
 	}
 
-	int value=lua_toboolean(lua, 1);
+	int value = lua_toboolean(lua, 1);
 
 	gboolean skip_tasklist = (gboolean)(value);
 
@@ -1068,7 +1108,7 @@ int c_set_skip_pager(lua_State *lua)
 		return 0;
 	}
 
-	int type=lua_type(lua, 1);
+	int type = lua_type(lua, 1);
 
 	if (type!=LUA_TBOOLEAN) {
 		luaL_error(lua, "set_skip_pager: %s", boolean_expected_as_indata_error);
@@ -1173,20 +1213,33 @@ int c_get_window_is_maximized_horisontally(lua_State *lua)
 int c_set_window_above(lua_State *lua)
 {
 	int top = lua_gettop(lua);
+	gboolean set_above;
 
-	if (top!=0) {
-		luaL_error(lua,"set_window_above: %s", no_indata_expected_error);
+	if (top>1) {
+		luaL_error(lua, "set_window_above: %s", one_indata_expected_error);
 		return 0;
 	}
+	else if (top==1) {
+		int type = lua_type(lua, 1);
+
+		if (type!=LUA_TBOOLEAN) {
+			luaL_error(lua, "set_window_above: %s", boolean_expected_as_indata_error);
+			return 0;
+		}
+
+		int value = lua_toboolean(lua, 1);
+		set_above=(gboolean)(value);
+	}
+	else {
+		set_above=TRUE;
+	}
 
 	WnckWindow *window = get_current_window();
-
 	if (!devilspie2_emulate) {
-
 		Window xid = wnck_window_get_xid(window);
 		devilspie2_change_state(devilspie2_window_get_xscreen(xid),
 		                     xid,
-		                     TRUE,
+		                     set_above,
 		                     my_wnck_atom_get("_NET_WM_STATE_ABOVE"),
 		                     0);
 	}
@@ -1201,20 +1254,34 @@ int c_set_window_above(lua_State *lua)
 int c_set_window_below(lua_State *lua)
 {
 	int top = lua_gettop(lua);
+	gboolean set_below;
 
-	if (top!=0) {
-		luaL_error(lua,"set_window_above: %s", no_indata_expected_error);
+	if (top>1) {
+		luaL_error(lua, "set_window_below: %s", one_indata_expected_error);
 		return 0;
 	}
+	else if (top==1) {
+		int type = lua_type(lua, 1);
+
+		if (type!=LUA_TBOOLEAN) {
+			luaL_error(lua, "set_window_below: %s", boolean_expected_as_indata_error);
+			return 0;
+		}
+
+		int value = lua_toboolean(lua, 1);
+		set_below=(gboolean)(value);
+	}
+	else {
+		set_below=TRUE;
+	}
 
 	WnckWindow *window = get_current_window();
-
 	if (!devilspie2_emulate) {
 
 		Window xid = wnck_window_get_xid(window);
 		devilspie2_change_state(devilspie2_window_get_xscreen(xid),
 		                     xid,
-		                     TRUE,
+		                     set_below,
 		                     my_wnck_atom_get("_NET_WM_STATE_BELOW"),
 		                     0);
 	}
@@ -1330,7 +1397,7 @@ int c_get_window_property(lua_State *lua)
 	}
 
 	//	gchar *property=
-	int type=lua_type(lua, 1);
+	int type = lua_type(lua, 1);
 
 	if (type!=LUA_TSTRING) {
 		luaL_error(lua,"get_window_property: %s",string_expected_as_indata_error);
@@ -1341,7 +1408,7 @@ int c_get_window_property(lua_State *lua)
 
 	WnckWindow *window = get_current_window();
 
-	gchar *result=NULL;
+	gchar *result = NULL;
 
 	if (window) {
 		result = my_wnck_get_string_property_latin1(wnck_window_get_xid(window),
@@ -1481,7 +1548,7 @@ int c_set_window_fullscreen(lua_State *lua)
 
 	WnckWindow *window = get_current_window();
 
-	int type=lua_type(lua, 1);
+	int type = lua_type(lua, 1);
 
 	if (type!=LUA_TBOOLEAN) {
 		luaL_error(lua, "set_window_fullscreen: %s",
@@ -1764,6 +1831,29 @@ int c_close_window(lua_State *lua)
 }
 
 
+/**
+ *
+ */
+int c_get_window_fullscreen(lua_State *lua)
+{
+	int top = lua_gettop(lua);
+	if (top != 0) {
+		luaL_error(lua, "is_fullscreen: %s", no_indata_expected_error);
+		return 0;
+	}
+
+	gboolean result = FALSE;
+
+	WnckWindow *window = get_current_window();
+	if (window) {
+		result = wnck_window_is_fullscreen(window);
+	}
+
+	lua_pushboolean(lua, result);
+
+	return 1;
+}
+
 /*
  * Devilspie:
 
